@@ -2,7 +2,9 @@
 
 pytest -v --rootdir . --junitxml data/pytest.xml -o 'junit_family = xunit2' \
   --deselect test_runBatchExamples.py::test_runBatchBlender \
-  --deselect  test_runBatchExamples.py::test_runBatchPuppeteerLighthouse
+  --deselect  test_runBatchExamples.py::test_runBatchPuppeteerLighthouse \
+  --deselect  test_runBatchExamples.py::test_runBatchTaurus \
+  --ignore DevWeb
 
 #   --deselect  test_runBatchExamples.py::test_runBatchPython
 #   --deselect test_runBatchExamples.py::test_runBatchJMeter \
